from langchain_community.document_loaders.parsers.audio import (
    OpenAIWhisperParser,
    OpenAIWhisperParserLocal,
    YandexSTTParser,
)

__all__ = ["OpenAIWhisperParser", "OpenAIWhisperParserLocal", "YandexSTTParser"]
